:github_url: https://github.com/merlinquantum/merlin

============
Installation
============

To install the Merlin Quantum package from PyPI, use the following command:

.. code-block:: bash

   pip install merlinquantum

You can also install the package from the source code for development purposes. Clone the repository and install it in editable mode:

.. code-block:: bash

   git clone ssh://github.com/merlinquantum/merlin.git
   cd merlin
   pip install -e ".[dev]"

You are set, you can now start building your first quantum layer!


